@@ -146,9 +146,15 @@ mod imp {
                 filter.add_mime_type("audio/*");
                 filters.append(&filter);
 
+                let xdg_music = match glib::user_special_dir(glib::UserDirectory::Music) {
+                    Some(p) => p,
+                    None => glib::current_dir(),
+                };
+
                 let dialog = gtk::FileDialog::builder()
                     .accept_label(&i18n("_Add Song"))
                     .filters(&filters)
+                    .initial_folder(&gio::File::for_path(&xdg_music))
                     .modal(true)
                     .title(&i18n("Open File"))
                     .build();
@@ -163,8 +169,14 @@ mod imp {
             });
             klass.install_action_async("queue.add-folder", None, |win, _, _| async move {
                 debug!("Window::win.add-folder()");
+                let xdg_music = match glib::user_special_dir(glib::UserDirectory::Music) {
+                    Some(p) => p,
+                    None => glib::current_dir(),
+                };
+
                 let dialog = gtk::FileDialog::builder()
                     .accept_label(&i18n("_Add Folder"))
+                    .initial_folder(&gio::File::for_path(&xdg_music))
                     .modal(true)
                     .title(&i18n("Open Folder"))
                     .build();
@@ -1391,19 +1403,23 @@ impl Window {
             if let Some(bg_colors) = song.cover_palette() {
                 let mut css = String::new();
 
+                css.push_str(":root {");
+
                 let n_colors = bg_colors.len();
                 for (i, color) in bg_colors.iter().enumerate().take(n_colors) {
-                    let s = format!("@define-color background_color_{} {};", i, color);
+                    let s = format!("--background-color-{}: {};", i, color);
                     css.push_str(&s);
                 }
 
-                for i in n_colors - 1..5 {
+                for i in n_colors + 1 - 1..5 {
                     css.push_str(&format!(
-                        "@define-color background_color_{} @window_bg_color;",
+                        "--background-color-{}: var(--window-bg-color);",
                         i
                     ));
                 }
 
+                css.push_str("}");
+
                 imp.provider.load_from_string(&css);
                 if !imp.main_stack.has_css_class("main-window") {
                     imp.main_stack.add_css_class("main-window");
